==> monster_menus-9.3.4.tar.gz: monster_menus/src/MMSearchAction/MMSearchActionManager.php <==
<?php

namespace Drupal\monster_menus\MMSearchAction;

use Drupal\Core\Cache\CacheBackendInterface;
use Drupal\Core\Extension\ModuleHandlerInterface;
use Drupal\Core\Plugin\DefaultPluginManager;

/**
 * Provides an MMTreeBrowserDisplay plugin manager.
 *
 * @see plugin_api
 */
class MMSearchActionManager extends DefaultPluginManager {

  /**
   * Constructs a MMTreeBrowserDisplayManager object.
   *
   * @param \Traversable $namespaces
   *   An object that implements \Traversable which contains the root paths
   *   keyed by the corresponding namespace to look for plugin implementations.
   * @param \Drupal\Core\Cache\CacheBackendInterface $cache_backend
   *   Cache backend instance to use.
   * @param \Drupal\Core\Extension\ModuleHandlerInterface $module_handler
   *   The module handler to invoke the alter hook with.
   */
  public function __construct(\Traversable $namespaces, CacheBackendInterface $cache_backend, ModuleHandlerInterface $module_handler) {
    parent::__construct('Plugin/MMSearchAction', $namespaces, $module_handler, 'Drupal\monster_menus\MMSearchAction\MMSearchActionInterface', 'Drupal\monster_menus\Annotation\MMSearchAction');
    $this->setCacheBackend($cache_backend, 'mm_tree_search_action_plugins');
  }

  /**
   * Gets a list of available actions.
   *
   * @return []
   *   An array with the action names as keys.
   */
  public function getAvailableActions(array $config) {
    $output = [];
    foreach ($this->getDefinitions() as $id => $definition) {
      $plugin = $this->createInstance($id, $config);
      if ($plugin->applies()) {
        $output[$id] = ['label' => $definition['label'], 'plugin' => $plugin, 'definition' => $definition];
      }
    }

    return $output;
  }

}

==> monster_menus-9.4.3.tar.gz: monster_menus/src/MMSearchAction/MMSearchActionManager.php <==
<?php

namespace Drupal\monster_menus\MMSearchAction;

use Drupal\monster_menus\Annotation\MMSearchAction;
use Drupal\Core\Cache\CacheBackendInterface;
use Drupal\Core\Extension\ModuleHandlerInterface;
use Drupal\Core\Plugin\DefaultPluginManager;

/**
 * Provides an MMTreeBrowserDisplay plugin manager.
 *
 * @see plugin_api
 */
class MMSearchActionManager extends DefaultPluginManager {

  /**
   * Constructs a MMTreeBrowserDisplayManager object.
   *
   * @param \Traversable $namespaces
   *   An object that implements \Traversable which contains the root paths
   *   keyed by the corresponding namespace to look for plugin implementations.
   * @param \Drupal\Core\Cache\CacheBackendInterface $cache_backend
   *   Cache backend instance to use.
   * @param \Drupal\Core\Extension\ModuleHandlerInterface $module_handler
   *   The module handler to invoke the alter hook with.
   */
  public function __construct(\Traversable $namespaces, CacheBackendInterface $cache_backend, ModuleHandlerInterface $module_handler) {
    parent::__construct('Plugin/MMSearchAction', $namespaces, $module_handler, MMSearchActionInterface::class, MMSearchAction::class);
    $this->setCacheBackend($cache_backend, 'mm_tree_search_action_plugins');
  }

  /**
   * Gets a list of available actions.
   *
   * @return []
   *   An array with the action names as keys.
   */
  public function getAvailableActions(array $config) {
    $output = [];
    foreach ($this->getDefinitions() as $id => $definition) {
      $plugin = $this->createInstance($id, $config);
      if ($plugin->applies()) {
        $output[$id] = ['label' => $definition['label'], 'plugin' => $plugin, 'definition' => $definition];
      }
    }

    return $output;
  }

}
